@@ -376,7 +376,7 @@ matches_text_list (GSList *text_list,
 		ECalComponentText *text;
 
 		text = l->data;
-		g_return_val_if_fail (text->value != NULL, FALSE);
+		g_assert (text->value != NULL);
 
 		if (e_util_utf8_strstrcasedecomp (text->value, str) != NULL) {
 			matches = TRUE;
@@ -1580,6 +1580,8 @@ e_cal_backend_sexp_func_time_day_end (ESExp *esexp,
  *
  * Determines biggest time window given by expressions "occur-in-range" in sexp.
  *
+ * Returns: %TRUE on success, %FALSE otherwise
+ *
  * Since: 2.32
  */
 gboolean
