@@ -110,13 +110,6 @@ backend_network_monitor_can_reach_cb (GObject *source_object,
 
 	e_backend_set_online (backend, host_is_reachable);
 
-	if (!host_is_reachable) {
-		ESource *source;
-
-		source = e_backend_get_source (backend);
-		e_source_set_connection_status (source, E_SOURCE_CONNECTION_STATUS_DISCONNECTED);
-	}
-
 	g_object_unref (backend);
 }
 
@@ -394,6 +387,23 @@ backend_source_authenticate_cb (ESource *source,
 	e_backend_schedule_authenticate	(backend, credentials);
 }
 
+static void
+backend_source_unset_last_credentials_required_arguments_cb (GObject *source_object,
+							     GAsyncResult *result,
+							     gpointer user_data)
+{
+	GError *local_error = NULL;
+
+	g_return_if_fail (E_IS_SOURCE (source_object));
+
+	e_source_unset_last_credentials_required_arguments_finish (E_SOURCE (source_object), result, &local_error);
+
+	if (local_error)
+		g_debug ("%s: Call failed: %s", G_STRFUNC, local_error->message);
+
+	g_clear_error (&local_error);
+}
+
 static void
 backend_set_source (EBackend *backend,
                     ESource *source)
@@ -504,6 +514,8 @@ backend_dispose (GObject *object)
 	if (priv->source) {
 		g_signal_handlers_disconnect_by_func (priv->source, backend_source_authenticate_cb, object);
 		e_source_set_connection_status (priv->source, E_SOURCE_CONNECTION_STATUS_DISCONNECTED);
+		e_source_unset_last_credentials_required_arguments (priv->source, NULL,
+			backend_source_unset_last_credentials_required_arguments_cb, NULL);
 	}
 
 	g_mutex_lock (&priv->authenticate_cancellable_lock);
@@ -567,21 +579,6 @@ backend_constructed (GObject *object)
 	}
 }
 
-static ESourceAuthenticationResult
-backend_authenticate_sync (EBackend *backend,
-			   const ENamedParameters *credentials,
-			   gchar **out_certificate_pem,
-			   GTlsCertificateFlags *out_certificate_errors,
-			   GCancellable *cancellable,
-			   GError **error)
-{
-	/* The default implementation just reports success, it's for backends
-	   which do not use (nor define) authentication routines, because
-	   they use different methods to get to the credentials. */
-
-	return E_SOURCE_AUTHENTICATION_ACCEPTED;
-}
-
 static gboolean
 backend_get_destination_address (EBackend *backend,
                                  gchar **host,
@@ -632,7 +629,6 @@ e_backend_class_init (EBackendClass *class)
 	object_class->finalize = backend_finalize;
 	object_class->constructed = backend_constructed;
 
-	class->authenticate_sync = backend_authenticate_sync;
 	class->get_destination_address = backend_get_destination_address;
 	class->prepare_shutdown = backend_prepare_shutdown;
 
@@ -905,7 +901,7 @@ e_backend_ref_main_context (EBackend *backend)
  * @reason: an #ESourceCredentialsReason, why the credentials are required
  * @certificate_pem: PEM-encoded secure connection certificate, or an empty string
  * @certificate_errors: a bit-or of #GTlsCertificateFlags for secure connection certificate
- * @op_error: (allow none): a #GError with a description of the previous credentials error, or %NULL
+ * @op_error: (allow-none): a #GError with a description of the previous credentials error, or %NULL
  * @cancellable: optional #GCancellable object, or %NULL
  * @error: return location for a #GError, or %NULL
  *
@@ -989,9 +985,8 @@ backend_credentials_required_thread (GTask *task,
  * @reason: an #ESourceCredentialsReason, why the credentials are required
  * @certificate_pem: PEM-encoded secure connection certificate, or an empty string
  * @certificate_errors: a bit-or of #GTlsCertificateFlags for secure connection certificate
- * @op_error: (allow none): a #GError with a description of the previous credentials error, or %NULL
+ * @op_error: (allow-none): a #GError with a description of the previous credentials error, or %NULL
  * @cancellable: optional #GCancellable object, or %NULL
- * @error: return location for a #GError, or %NULL
  *
  * Asynchronously calls the e_backend_credentials_required_sync() on the @backend,
  * to inform clients that credentials are required.
@@ -1086,9 +1081,9 @@ backend_scheduled_credentials_required_done_cb (GObject *source_object,
  * @reason: an #ESourceCredentialsReason, why the credentials are required
  * @certificate_pem: PEM-encoded secure connection certificate, or an empty string
  * @certificate_errors: a bit-or of #GTlsCertificateFlags for secure connection certificate
- * @op_error: (allow none): a #GError with a description of the previous credentials error, or %NULL
+ * @op_error: (allow-none): a #GError with a description of the previous credentials error, or %NULL
  * @cancellable: optional #GCancellable object, or %NULL
- * @who_calls: (allow none): an identification who calls this
+ * @who_calls: (allow-none): an identification who calls this
  *
  * Asynchronously invokes e_backend_credentials_required(), but installs its
  * own callback which only prints a runtime warning on the console when
@@ -1116,7 +1111,7 @@ e_backend_schedule_credentials_required (EBackend *backend,
 /**
  * e_backend_schedule_authenticate:
  * @backend: an #EBackend
- * @credentials: (allow none): a credentials to use to authenticate, or %NULL
+ * @credentials: (allow-none): a credentials to use to authenticate, or %NULL
  *
  * Schedules a new authenticate session, cancelling any previously run.
  * This is usually done automatically, when an 'authenticate' signal is
@@ -1152,31 +1147,6 @@ e_backend_schedule_authenticate	(EBackend *backend,
 	g_clear_object (&cancellable);
 }
 
-/**
- * e_backend_ensure_source_status_connected:
- * @backend: an #EBackend
- *
- * Makes sure that the associated ESource::connection-status is connected. This is
- * useful in cases when the backend can connect to the destination without invoking
- * EBackend::authenticate_sync, possibly through e_backend_schedule_authenticate().
- *
- * Since: 3.16.4
- **/
-void
-e_backend_ensure_source_status_connected (EBackend *backend)
-{
-	ESource *source;
-
-	g_return_if_fail (E_IS_BACKEND (backend));
-
-	source = e_backend_get_source (backend);
-
-	g_return_if_fail (E_IS_SOURCE (source));
-
-	if (e_source_get_connection_status (source) != E_SOURCE_CONNECTION_STATUS_CONNECTED)
-		e_source_set_connection_status (source, E_SOURCE_CONNECTION_STATUS_CONNECTED);
-}
-
 /**
  * e_backend_get_user_prompter:
  * @backend: an #EBackend
