@@ -70,51 +70,38 @@ struct _EDataFactoryClass {
 
 	const gchar *factory_object_path;
 	const gchar *data_object_path_prefix;
-
-	/* Signals */
-	void		(*backend_created)	(EDataFactory *data_factory,
-						 EBackend *backend);
+	const gchar *subprocess_object_path_prefix;
+	const gchar *subprocess_bus_name_prefix;
 
 	/* Virtual methods */
 	GDBusInterfaceSkeleton *
 			(*get_dbus_interface_skeleton)
 						(EDBusServer *server);
-
-	gchar *		(*data_open)		(EDataFactory *data_factory,
-						 EBackend *backend,
-						 GDBusConnection *connection,
-						 GError **error);
+	const gchar *	(*get_factory_name)	(EBackendFactory *backend_factory);
+	void		(*complete_open)	(EDataFactory *data_factory,
+						 GDBusMethodInvocation *invocation,
+						 const gchar *object_path,
+						 const gchar *bus_name,
+						 const gchar *extension_name);
 
 	gpointer reserved[15];
 };
 
 GType		e_data_factory_get_type		(void) G_GNUC_CONST;
-EBackend *	e_data_factory_ref_backend	(EDataFactory *data_factory,
-						 const gchar *hash_key,
-						 ESource *source);
-EBackend *	e_data_factory_ref_initable_backend
-						(EDataFactory *data_factory,
-						 const gchar *hash_key,
-						 ESource *source,
-						 GCancellable *cancellable,
-						 GError **error);
 EBackendFactory *
 		e_data_factory_ref_backend_factory
 						(EDataFactory *data_factory,
-						 const gchar *hash_key);
+						 const gchar *backend_name,
+						 const gchar *extension_name);
 ESourceRegistry *
 		e_data_factory_get_registry	(EDataFactory *data_factory);
-GSList *	e_data_factory_list_backends	(EDataFactory *data_factory);
-gchar *		e_data_factory_open_backend	(EDataFactory *data_factory,
-						 GDBusConnection *connection,
-						 const gchar *sender,
+gchar *		e_data_factory_construct_path	(EDataFactory *data_factory);
+void		e_data_factory_spawn_subprocess_backend
+						(EDataFactory *data_factory,
+						 GDBusMethodInvocation *invocation,
 						 const gchar *uid,
 						 const gchar *extension_name,
-						 GError **error);
-gchar *		e_data_factory_construct_path	(EDataFactory *data_factory);
-void		e_data_factory_set_backend_callbacks
-						(EDataFactory *data_factory,
-						 EBackend *backend);
+						 const gchar *subprocess_path);
 
 G_END_DECLS
 
