@@ -290,9 +290,10 @@ google_add_found_source (ECollectionBackend *collection,
 		e_source_backend_set_backend_name (backend, provider);
 
 		e_source_set_display_name (source, display_name);
+
 		/* Also check whether the color format is as expected; it cannot
 		   be used gdk_rgba_parse here, because it required gdk/gtk. */
-		if (source_type != E_WEBDAV_DISCOVER_SUPPORTS_CONTACTS && color &&
+		if (is_new && source_type != E_WEBDAV_DISCOVER_SUPPORTS_CONTACTS && color &&
 		    sscanf (color, "#%02x%02x%02x", &rr, &gg, &bb) == 3) {
 			gchar *safe_color;
 
@@ -355,7 +356,9 @@ google_backend_authenticate_sync (EBackend *backend,
 	g_list_foreach (sources, google_add_uid_to_hashtable, known_sources);
 	g_list_free_full (sources, g_object_unref);
 
-	if (e_source_collection_get_calendar_enabled (collection_extension) &&
+	google_backend_calendar_update_auth_method (source);
+
+	if (e_source_collection_get_calendar_enabled (collection_extension) && e_source_goa_get_calendar_url (goa_extension) &&
 	    e_webdav_discover_sources_sync (source, e_source_goa_get_calendar_url (goa_extension), E_WEBDAV_DISCOVER_SUPPORTS_NONE,
 		credentials, out_certificate_pem, out_certificate_errors,
 		&discovered_sources, NULL, cancellable, &local_error)) {
@@ -601,6 +604,10 @@ google_backend_child_added (ECollectionBackend *backend,
 	const gchar *extension_name;
 	gboolean is_mail = FALSE;
 
+	/* Chain up to parent's child_added() method. */
+	E_COLLECTION_BACKEND_CLASS (e_google_backend_parent_class)->
+		child_added (backend, child_source);
+
 	collection_source = e_backend_get_source (E_BACKEND (backend));
 
 	extension_name = E_SOURCE_EXTENSION_MAIL_ACCOUNT;
@@ -648,6 +655,20 @@ google_backend_child_added (ECollectionBackend *backend,
 	 *     Many-to-one property bindinds tend not to work so well. */
 	extension_name = E_SOURCE_EXTENSION_CALENDAR;
 	if (e_source_has_extension (child_source, extension_name)) {
+		ESourceAlarms *alarms_extension;
+
+		/* To not notify about past reminders. */
+		alarms_extension = e_source_get_extension (child_source, E_SOURCE_EXTENSION_ALARMS);
+		if (!e_source_alarms_get_last_notified (alarms_extension)) {
+			GTimeVal today_tv;
+			gchar *today;
+
+			g_get_current_time (&today_tv);
+			today = g_time_val_to_iso8601 (&today_tv);
+			e_source_alarms_set_last_notified (alarms_extension, today);
+			g_free (today);
+		}
+
 		google_backend_calendar_update_auth_method (child_source);
 		g_signal_connect (
 			child_source, "notify::oauth2-support",
@@ -668,10 +689,6 @@ google_backend_child_added (ECollectionBackend *backend,
 			G_CALLBACK (google_backend_contacts_update_auth_method),
 			NULL);
 	}
-
-	/* Chain up to parent's child_added() method. */
-	E_COLLECTION_BACKEND_CLASS (e_google_backend_parent_class)->
-		child_added (backend, child_source);
 }
 
 static void
