@@ -218,9 +218,10 @@ owncloud_add_found_source (ECollectionBackend *collection,
 		e_source_backend_set_backend_name (backend, provider);
 
 		e_source_set_display_name (source, display_name);
+
 		/* Also check whether the color format is as expected; it cannot
 		   be used gdk_rgba_parse here, because it required gdk/gtk. */
-		if (source_type != E_WEBDAV_DISCOVER_SUPPORTS_CONTACTS && color &&
+		if (is_new && source_type != E_WEBDAV_DISCOVER_SUPPORTS_CONTACTS && color &&
 		    sscanf (color, "#%02x%02x%02x", &rr, &gg, &bb) == 3) {
 			gchar *safe_color;
 
@@ -319,7 +320,7 @@ owncloud_backend_authenticate_sync (EBackend *backend,
 	g_list_foreach (sources, owncloud_add_uid_to_hashtable, known_sources);
 	g_list_free_full (sources, g_object_unref);
 
-	if (e_source_collection_get_calendar_enabled (collection_extension) &&
+	if (e_source_collection_get_calendar_enabled (collection_extension) && e_source_goa_get_calendar_url (goa_extension) &&
 	    e_webdav_discover_sources_sync (source, e_source_goa_get_calendar_url (goa_extension), E_WEBDAV_DISCOVER_SUPPORTS_NONE,
 		credentials, out_certificate_pem, out_certificate_errors,
 		&discovered_sources, NULL, cancellable, &local_error)) {
@@ -348,6 +349,7 @@ owncloud_backend_authenticate_sync (EBackend *backend,
 
 	/* Skip search in this URL, if the previous one returned also contacts - it's quite likely it did */
 	if (!contacts_found && !local_error && e_source_collection_get_contacts_enabled (collection_extension) &&
+	    e_source_goa_get_contacts_url (goa_extension) &&
 	    e_webdav_discover_sources_sync (source, e_source_goa_get_contacts_url (goa_extension), E_WEBDAV_DISCOVER_SUPPORTS_CONTACTS,
 		credentials, out_certificate_pem, out_certificate_errors,
 		&discovered_sources, NULL, cancellable, &local_error)) {
